@@ -46,13 +46,14 @@ extern "C" {
 /** Sequencer handle */
 typedef struct _snd_seq snd_seq_t;
 
-/** Allocate and initialize array on stack \internal */
+#ifndef DOC_HIDDEN
 #define SND_ALLOCA(type,ptr) \
 do {\
 	assert(ptr);\
 	*ptr = (type##_t *)alloca(type##_sizeof());\
 	memset(*ptr, 0, type##_sizeof());\
 } while (0)
+#endif
 
 /**
  * sequencer opening stream types
@@ -315,7 +316,6 @@ int snd_seq_port_subscribe_get_time_real(const snd_seq_port_subscribe_t *info);
 void snd_seq_port_subscribe_set_sender(snd_seq_port_subscribe_t *info, const snd_seq_addr_t *addr);
 void snd_seq_port_subscribe_set_dest(snd_seq_port_subscribe_t *info, const snd_seq_addr_t *addr);
 void snd_seq_port_subscribe_set_queue(snd_seq_port_subscribe_t *info, int q);
-void snd_seq_port_subscribe_set_voices(snd_seq_port_subscribe_t *info, unsigned int voices);
 void snd_seq_port_subscribe_set_exclusive(snd_seq_port_subscribe_t *info, int val);
 void snd_seq_port_subscribe_set_time_update(snd_seq_port_subscribe_t *info, int val);
 void snd_seq_port_subscribe_set_time_real(snd_seq_port_subscribe_t *info, int val);
@@ -360,7 +360,7 @@ void snd_seq_query_subscribe_set_client(snd_seq_query_subscribe_t *info, int cli
 void snd_seq_query_subscribe_set_port(snd_seq_query_subscribe_t *info, int port);
 void snd_seq_query_subscribe_set_root(snd_seq_query_subscribe_t *info, const snd_seq_addr_t *addr);
 void snd_seq_query_subscribe_set_type(snd_seq_query_subscribe_t *info, snd_seq_query_subs_type_t type);
-void snd_seq_query_subscribe_set_index(snd_seq_query_subscribe_t *info, int index);
+void snd_seq_query_subscribe_set_index(snd_seq_query_subscribe_t *info, int _index);
 
 int snd_seq_query_port_subscribers(snd_seq_t *seq, snd_seq_query_subscribe_t * subs);
 
