@@ -31,7 +31,7 @@ const char *_snd_module_seq_hw = "";
 
 #define SNDRV_FILE_SEQ		"/dev/snd/seq"
 #define SNDRV_FILE_ALOADSEQ	"/dev/aloadSEQ"
-#define SNDRV_SEQ_VERSION_MAX	SNDRV_PROTOCOL_VERSION(1, 0, 0)
+#define SNDRV_SEQ_VERSION_MAX	SNDRV_PROTOCOL_VERSION(1, 0, 1)
 
 typedef struct {
 	int fd;
@@ -378,38 +378,38 @@ static int snd_seq_hw_query_next_port(snd_seq_t *seq, snd_seq_port_info_t *info)
 }
 
 snd_seq_ops_t snd_seq_hw_ops = {
-	close: snd_seq_hw_close,
-	nonblock: snd_seq_hw_nonblock,
-	system_info: snd_seq_hw_system_info,
-	get_client_info: snd_seq_hw_get_client_info,
-	set_client_info: snd_seq_hw_set_client_info,
-	create_port: snd_seq_hw_create_port,
-	delete_port: snd_seq_hw_delete_port,
-	get_port_info: snd_seq_hw_get_port_info,
-	set_port_info: snd_seq_hw_set_port_info,
-	get_port_subscription: snd_seq_hw_get_port_subscription,
-	subscribe_port: snd_seq_hw_subscribe_port,
-	unsubscribe_port: snd_seq_hw_unsubscribe_port,
-	query_port_subscribers: snd_seq_hw_query_port_subscribers,
-	get_queue_status: snd_seq_hw_get_queue_status,
-	get_queue_tempo: snd_seq_hw_get_queue_tempo,
-	set_queue_tempo: snd_seq_hw_set_queue_tempo,
-	get_queue_timer: snd_seq_hw_get_queue_timer,
-	set_queue_timer: snd_seq_hw_set_queue_timer,
-	get_queue_client: snd_seq_hw_get_queue_client,
-	set_queue_client: snd_seq_hw_set_queue_client,
-	create_queue: snd_seq_hw_create_queue,
-	delete_queue: snd_seq_hw_delete_queue,
-	get_queue_info: snd_seq_hw_get_queue_info,
-	set_queue_info: snd_seq_hw_set_queue_info,
-	get_named_queue: snd_seq_hw_get_named_queue,
-	write: snd_seq_hw_write,
-	read: snd_seq_hw_read,
-	remove_events: snd_seq_hw_remove_events,
-	get_client_pool: snd_seq_hw_get_client_pool,
-	set_client_pool: snd_seq_hw_set_client_pool,
-	query_next_client: snd_seq_hw_query_next_client,
-	query_next_port: snd_seq_hw_query_next_port,
+	.close = snd_seq_hw_close,
+	.nonblock = snd_seq_hw_nonblock,
+	.system_info = snd_seq_hw_system_info,
+	.get_client_info = snd_seq_hw_get_client_info,
+	.set_client_info = snd_seq_hw_set_client_info,
+	.create_port = snd_seq_hw_create_port,
+	.delete_port = snd_seq_hw_delete_port,
+	.get_port_info = snd_seq_hw_get_port_info,
+	.set_port_info = snd_seq_hw_set_port_info,
+	.get_port_subscription = snd_seq_hw_get_port_subscription,
+	.subscribe_port = snd_seq_hw_subscribe_port,
+	.unsubscribe_port = snd_seq_hw_unsubscribe_port,
+	.query_port_subscribers = snd_seq_hw_query_port_subscribers,
+	.get_queue_status = snd_seq_hw_get_queue_status,
+	.get_queue_tempo = snd_seq_hw_get_queue_tempo,
+	.set_queue_tempo = snd_seq_hw_set_queue_tempo,
+	.get_queue_timer = snd_seq_hw_get_queue_timer,
+	.set_queue_timer = snd_seq_hw_set_queue_timer,
+	.get_queue_client = snd_seq_hw_get_queue_client,
+	.set_queue_client = snd_seq_hw_set_queue_client,
+	.create_queue = snd_seq_hw_create_queue,
+	.delete_queue = snd_seq_hw_delete_queue,
+	.get_queue_info = snd_seq_hw_get_queue_info,
+	.set_queue_info = snd_seq_hw_set_queue_info,
+	.get_named_queue = snd_seq_hw_get_named_queue,
+	.write = snd_seq_hw_write,
+	.read = snd_seq_hw_read,
+	.remove_events = snd_seq_hw_remove_events,
+	.get_client_pool = snd_seq_hw_get_client_pool,
+	.set_client_pool = snd_seq_hw_set_client_pool,
+	.query_next_client = snd_seq_hw_query_next_client,
+	.query_next_port = snd_seq_hw_query_next_port,
 };
 
 int snd_seq_hw_open(snd_seq_t **handle, const char *name, int streams, int mode)
